surf: Visualization of algebraic curves, algebraic surfaces and hyperplane sections of surfaces
===============================================================================================

Description
-----------

surf is a tool to visualize some real algebraic geometry: plane
algebraic curves, algebraic surfaces and hyperplane sections of
surfaces. surf is script driven and has (optionally) a nifty GUI using
the Gtk widget set.

This is used by the Singular Jupyter kernel to produce 3D plots.

License
-------

GPL version 2 or later


Upstream Contact
----------------

http://surf.sourceforge.net (although the project is essentially dead)

Dependencies
------------

-  cups (optional)
-  GNU flex Version 2.5 or higher
-  GTK+ Version 1.2.0 or higher (optional)
-  POSIX Threads
-  GNU MP(gmp) Version 2 or higher
-  lib-tiff
-  lib-jpeg
-  zlib
-  ps2pdf (optional)

This package is "experimental" because not all of these dependencies are
packaged with Sage.
